storage

package
v0.0.0-...-a2b69cf Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 9, 2025 License: MIT Imports: 16 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	Container = &StorageContainer{}
)

Initialize a object storage container singleton instance

Functions

func InitializeStorageContainer

func InitializeStorageContainer(config *settings.Config) error

InitializeStorageContainer initializes the current object storage according to the config

Types

type LocalFileSystemObjectStorage

type LocalFileSystemObjectStorage struct {
	// contains filtered or unexported fields
}

LocalFileSystemObjectStorage represents local file system object storage

func NewLocalFileSystemObjectStorage

func NewLocalFileSystemObjectStorage(config *settings.Config, pathPrefix string) (*LocalFileSystemObjectStorage, error)

NewLocalFileSystemObjectStorage returns a local file system object storage

func (*LocalFileSystemObjectStorage) Delete

func (s *LocalFileSystemObjectStorage) Delete(ctx core.Context, path string) error

Delete returns whether delete the object according to specified the file path successfully

func (*LocalFileSystemObjectStorage) Exists

func (s *LocalFileSystemObjectStorage) Exists(ctx core.Context, path string) (bool, error)

Exists returns whether the file exists

func (*LocalFileSystemObjectStorage) Read

Read returns the object instance according to specified the file path

func (*LocalFileSystemObjectStorage) Save

Save returns whether save the object instance successfully

type MinIOObjectStorage

type MinIOObjectStorage struct {
	// contains filtered or unexported fields
}

MinIOObjectStorage represents MinIO object storage

func NewMinIOObjectStorage

func NewMinIOObjectStorage(config *settings.Config, pathPrefix string) (*MinIOObjectStorage, error)

NewMinIOObjectStorage returns a MinIO object storage

func (*MinIOObjectStorage) Delete

func (s *MinIOObjectStorage) Delete(ctx core.Context, path string) error

Delete returns whether delete the object according to specified the file path successfully

func (*MinIOObjectStorage) Exists

func (s *MinIOObjectStorage) Exists(ctx core.Context, path string) (bool, error)

Exists returns whether the file exists

func (*MinIOObjectStorage) Read

Read returns the object instance according to specified the file path

func (*MinIOObjectStorage) Save

func (s *MinIOObjectStorage) Save(ctx core.Context, path string, object ObjectInStorage) error

Save returns whether save the object instance successfully

type ObjectInStorage

type ObjectInStorage interface {
	io.ReadCloser
	io.Seeker
}

ObjectInStorage represents the object instance in the storage

type ObjectStorage

type ObjectStorage interface {
	Exists(ctx core.Context, path string) (bool, error)
	Read(ctx core.Context, path string) (ObjectInStorage, error)
	Save(ctx core.Context, path string, object ObjectInStorage) error
	Delete(ctx core.Context, path string) error
}

ObjectStorage represents an object storage to store file object

type StorageContainer

type StorageContainer struct {
	// contains filtered or unexported fields
}

StorageContainer contains the current object storage

func (*StorageContainer) DeleteAvatar

func (s *StorageContainer) DeleteAvatar(ctx core.Context, path string) error

DeleteAvatar returns whether delete the avatar file from the current avatar object storage successfully

func (*StorageContainer) DeleteTransactionPicture

func (s *StorageContainer) DeleteTransactionPicture(ctx core.Context, path string) error

DeleteTransactionPicture returns whether delete the transaction picture file from the current transaction picture object storage successfully

func (*StorageContainer) ExistsAvatar

func (s *StorageContainer) ExistsAvatar(ctx core.Context, path string) (bool, error)

ExistsAvatar returns whether the avatar file exists from the current avatar object storage

func (*StorageContainer) ExistsTransactionPicture

func (s *StorageContainer) ExistsTransactionPicture(ctx core.Context, path string) (bool, error)

ExistsTransactionPicture returns whether the transaction picture file exists from the current transaction picture object storage

func (*StorageContainer) ReadAvatar

func (s *StorageContainer) ReadAvatar(ctx core.Context, path string) (ObjectInStorage, error)

ReadAvatar returns the avatar file from the current avatar object storage

func (*StorageContainer) ReadTransactionPicture

func (s *StorageContainer) ReadTransactionPicture(ctx core.Context, path string) (ObjectInStorage, error)

ReadTransactionPicture returns the transaction picture file from the current transaction picture object storage

func (*StorageContainer) SaveAvatar

func (s *StorageContainer) SaveAvatar(ctx core.Context, path string, object ObjectInStorage) error

SaveAvatar returns whether save the avatar file into the current avatar object storage successfully

func (*StorageContainer) SaveTransactionPicture

func (s *StorageContainer) SaveTransactionPicture(ctx core.Context, path string, object ObjectInStorage) error

SaveTransactionPicture returns whether save the transaction picture file into the current transaction picture object storage successfully

type WebDAVObjectStorage

type WebDAVObjectStorage struct {
	// contains filtered or unexported fields
}

WebDAVObjectStorage represents WebDAV object storage

func NewWebDAVObjectStorage

func NewWebDAVObjectStorage(config *settings.Config, pathPrefix string) (*WebDAVObjectStorage, error)

NewWebDAVObjectStorage returns a WebDAV object storage

func (*WebDAVObjectStorage) Delete

func (s *WebDAVObjectStorage) Delete(ctx core.Context, path string) error

Delete returns whether delete the object according to specified the file path successfully

func (*WebDAVObjectStorage) Exists

func (s *WebDAVObjectStorage) Exists(ctx core.Context, path string) (bool, error)

Exists returns whether the file exists

func (*WebDAVObjectStorage) Read

Read returns the object instance according to specified the file path

func (*WebDAVObjectStorage) Save

func (s *WebDAVObjectStorage) Save(ctx core.Context, path string, object ObjectInStorage) error

Save returns whether save the object instance successfully

Jump to